@@ -5,10 +5,11 @@ import pandas as pd
 from botocore.exceptions import ClientError
 
 def aws_client_factory(
-    aws_access_key: str,
-    aws_secret_key: str,
+    aws_access_key: str = None,
+    aws_secret_key: str = None,
     aws_region: str = 'us-east-1',
-    type: str = 'athena'
+    type: str = 'athena',
+    profile_name: str = None
 ):
     """
     Factory function to create and return initialized AWS Athena and S3 clients.
@@ -30,11 +31,17 @@ def aws_client_factory(
         Initialized AWS client for Athena or S3 based on the type specified.
     """
 
-    session = boto3.Session(
-        aws_access_key_id=aws_access_key,
-        aws_secret_access_key=aws_secret_key,
-        region_name=aws_region
-    )
+    if aws_access_key is not None and aws_secret_key is not None:
+        session = boto3.Session(
+            aws_access_key_id=aws_access_key,
+            aws_secret_access_key=aws_secret_key,
+            region_name=aws_region
+        )
+    elif profile_name is not None:
+        session = boto3.Session(profile_name=profile_name, region_name=aws_region)
+    else:
+        session = boto3.Session(region_name=aws_region)
+
     if type == 'athena':
         return session.client('athena')
     elif type == 's3':
